@@ -326,7 +326,9 @@ impl DoviRpu {
 
         header.nlq_method_idc = Some(0);
         header.nlq_num_pivots_minus2 = Some(0);
-        header.num_x_partitions_minus1 = 2046;
+
+        // BL is always 10 bit in current spec
+        header.nlq_pred_pivot_value = Some([0, 1023]);
 
         if let Some(ref mut rpu_data_nlq) = self.rpu_data_nlq {
             rpu_data_nlq.convert_to_mel();
@@ -348,6 +350,7 @@ impl DoviRpu {
 
         header.nlq_method_idc = None;
         header.nlq_num_pivots_minus2 = None;
+        header.nlq_pred_pivot_value = None;
 
         header.num_x_partitions_minus1 = 0;
         header.num_y_partitions_minus1 = 0;
