@@ -6,6 +6,8 @@ use serde::Serialize;
 
 use super::{dovi_rpu::DoviRpu, NUM_COMPONENTS};
 
+const NLQ_NUM_PIVOTS: usize = 2;
+
 #[derive(Default, Debug, Clone)]
 #[cfg_attr(feature = "serde_feature", derive(Serialize))]
 pub struct RpuDataHeader {
@@ -37,6 +39,7 @@ pub struct RpuDataHeader {
     pub pred_pivot_value: [Vec<u64>; NUM_COMPONENTS],
     pub nlq_method_idc: Option<u8>,
     pub nlq_num_pivots_minus2: Option<u8>,
+    pub nlq_pred_pivot_value: Option<[u64; NLQ_NUM_PIVOTS]>,
     pub num_x_partitions_minus1: u64,
     pub num_y_partitions_minus1: u64,
 }
@@ -96,6 +99,8 @@ impl RpuDataHeader {
                     rpu_nal.mapping_color_space = reader.get_ue()?;
                     rpu_nal.mapping_chroma_format_idc = reader.get_ue()?;
 
+                    let bl_bit_depth = (rpu_nal.bl_bit_depth_minus8 + 8) as usize;
+
                     for cmp in 0..NUM_COMPONENTS {
                         rpu_nal.num_pivots_minus_2[cmp] = reader.get_ue()?;
 
@@ -104,8 +109,7 @@ impl RpuDataHeader {
                             .resize_with(pivot_idx_count, Default::default);
 
                         for pivot_idx in 0..pivot_idx_count {
-                            rpu_nal.pred_pivot_value[cmp][pivot_idx] =
-                                reader.get_n((rpu_nal.bl_bit_depth_minus8 + 8) as usize);
+                            rpu_nal.pred_pivot_value[cmp][pivot_idx] = reader.get_n(bl_bit_depth);
                         }
                     }
 
@@ -113,6 +117,13 @@ impl RpuDataHeader {
                     if rpu_nal.rpu_format & 0x700 == 0 && !rpu_nal.disable_residual_flag {
                         rpu_nal.nlq_method_idc = Some(reader.get_n(3));
                         rpu_nal.nlq_num_pivots_minus2 = Some(0);
+
+                        let mut nlq_pred_pivot_value = [0; NLQ_NUM_PIVOTS];
+                        nlq_pred_pivot_value
+                            .iter_mut()
+                            .for_each(|pv| *pv = reader.get_n(bl_bit_depth));
+
+                        rpu_nal.nlq_pred_pivot_value = Some(nlq_pred_pivot_value);
                     }
 
                     rpu_nal.num_x_partitions_minus1 = reader.get_ue()?;
@@ -145,12 +156,27 @@ impl RpuDataHeader {
                     self.nlq_num_pivots_minus2.is_none(),
                     "profile 5: nlq_num_pivots_minus2 should be undefined"
                 );
+                ensure!(
+                    self.nlq_pred_pivot_value.is_none(),
+                    "profile 5: nlq_pred_pivot_value should be undefined"
+                );
             }
             7 => {
                 ensure!(
                     self.vdr_rpu_profile == 1,
                     "profile 7: vdr_rpu_profile should be 1"
                 );
+                ensure!(
+                    self.nlq_pred_pivot_value.is_some(),
+                    "profile 7: nlq_pred_pivot_value should be defined"
+                );
+
+                if let Some(nlq_pred_pivot_value) = self.nlq_pred_pivot_value {
+                    ensure!(
+                        nlq_pred_pivot_value.iter().sum::<u64>() == 1023,
+                        "profile 7: nlq_pred_pivot_value elements should add up to the BL bit depth"
+                    );
+                }
             }
             8 => {
                 ensure!(
@@ -165,6 +191,10 @@ impl RpuDataHeader {
                     self.nlq_num_pivots_minus2.is_none(),
                     "profile 8: nlq_num_pivots_minus2 should be undefined"
                 );
+                ensure!(
+                    self.nlq_pred_pivot_value.is_none(),
+                    "profile 8: nlq_pred_pivot_value should be undefined"
+                );
             }
             _ => (),
         };
@@ -285,6 +315,15 @@ impl RpuDataHeader {
                         if let Some(nlq_method_idc) = self.nlq_method_idc {
                             writer.write_n(&nlq_method_idc.to_be_bytes(), 3);
                         }
+
+                        if let Some(nlq_pred_pivot_value) = &self.nlq_pred_pivot_value {
+                            nlq_pred_pivot_value.iter().for_each(|pv| {
+                                writer.write_n(
+                                    &pv.to_be_bytes(),
+                                    (self.bl_bit_depth_minus8 + 8) as usize,
+                                )
+                            });
+                        }
                     }
 
                     writer.write_ue(self.num_x_partitions_minus1);
@@ -324,6 +363,7 @@ impl RpuDataHeader {
             pred_pivot_value: [vec![0, 1023], vec![0, 1023], vec![0, 1023]],
             nlq_method_idc: None,
             nlq_num_pivots_minus2: None,
+            nlq_pred_pivot_value: None,
             num_x_partitions_minus1: 0,
             num_y_partitions_minus1: 0,
         }
