@@ -10,7 +10,7 @@ use super::rpu_data_nlq::RpuDataNlq;
 
 use super::NUM_COMPONENTS;
 
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 #[cfg_attr(feature = "serde_feature", derive(Serialize))]
 pub struct RpuDataMapping {
     pub mapping_idc: [Vec<u64>; NUM_COMPONENTS],
@@ -318,7 +318,7 @@ impl RpuDataMapping {
         Ok(())
     }
 
-    pub fn p5_to_p81(&mut self) {
+    pub fn set_empty_p81_mapping(&mut self) {
         self.mapping_idc.iter_mut().for_each(|v| {
             v.clear();
             v.push(0);
